import IGCExtentProvider from "../../common/IGCExtentProvider";
import IGCManager from "../../common/IGCManager";
import IExtentStore from "../../common/persistence/IExtentStore";
import ILogger from "../generated/utils/ILogger";
declare enum Status {
    Initializing = 0,
    Running = 1,
    Closing = 2,
    Closed = 3
}
/**
 * GC manager to clean up unused extents mapped local files based on mark and sweep
 * algorithm.
 *
 * In the future, GC manager can also help merging small extent mapped files
 * into one big file to improve the performance.
 *
 * @export
 * @class BlobGCManager
 * @implements {IGCManager}
 */
export default class BlobGCManager implements IGCManager {
    private readonly referredExtentsProvider;
    private readonly allExtentsProvider;
    private readonly extentStore;
    private readonly errorHandler;
    private readonly logger;
    readonly gcIntervalInMS: number;
    private _status;
    private emitter;
    /**
     * Creates an instance of BlobGCManager.
     *
     * @param {IBlobMetadataStore} blobDataStore
     * @param {(err: Error) => void} errorHandler Error handler callback to handle critical errors during GC loop
     *                                            When an error happens, GC loop will close automatically
     * @param {ILogger} logger
     * @param {number} [gcIntervalInMS=DEFAULT_GC_INTERVAL_MS]
     * @memberof BlobGCManager
     */
    constructor(referredExtentsProvider: IGCExtentProvider, allExtentsProvider: IGCExtentProvider, extentStore: IExtentStore, errorHandler: (err: Error) => void, logger: ILogger, gcIntervalInMS?: number);
    readonly status: Status;
    /**
     * Initialize and start GC manager.
     *
     * @returns {Promise<void>}
     * @memberof BlobGCManager
     */
    start(): Promise<void>;
    close(): Promise<void>;
    private markSweepLoop;
    /**
     * Typical mark-sweep GC algorithm.
     *
     * @private
     * @returns {Promise<void>}
     * @memberof BlobGCManager
     */
    private markSweep;
    private getAllExtents;
    private sleep;
}
export {};
//# sourceMappingURL=BlobGCManager.d.ts.map