import Context from "../Context";
import MiddlewareError from "../errors/MiddlewareError";
import IResponse from "../IResponse";
import { NextFunction } from "../MiddlewareFactory";
import ILogger from "../utils/ILogger";
/**
 * ErrorMiddleware handles following 2 kinds of errors thrown from previous middleware or handlers:
 *
 * 1. MiddlewareError will be serialized.
 *    This includes most of expected errors, such as 4XX or some 5xx errors are MiddlewareError.
 *
 * 2. Other unexpected errors will be serialized to 500 Internal Server error directly.
 *    Every this kind of error should be carefully checked, and consider to handle it as a MiddlewareError.
 *
 * @export
 * @param {Context} context
 * @param {(MiddlewareError | Error)} err A MiddlewareError or Error object
 * @param {Request} _req An express compatible Request object
 * @param {Response} res An express compatible Response object
 * @param {NextFunction} next An express middleware next callback
 * @param {ILogger} logger A valid logger
 * @returns {void}
 */
export default function errorMiddleware(context: Context, err: MiddlewareError | Error, res: IResponse, next: NextFunction, logger: ILogger): void;
//# sourceMappingURL=error.middleware.d.ts.map