/// <reference types="node" />
import * as Models from "../generated/artifacts/models";
import Context from "../generated/Context";
import IServiceHandler from "../generated/handlers/IServiceHandler";
import BaseHandler from "./BaseHandler";
/**
 * ServiceHandler handles Azure Storage Blob service related requests.
 *
 * @export
 * @class ServiceHandler
 * @implements {IHandler}
 */
export default class ServiceHandler extends BaseHandler implements IServiceHandler {
    /**
     * Default service properties.
     *
     * @private
     * @memberof ServiceHandler
     */
    private readonly defaultServiceProperties;
    getUserDelegationKey(keyInfo: Models.KeyInfo, options: Models.ServiceGetUserDelegationKeyOptionalParams, context: Context): Promise<Models.ServiceGetUserDelegationKeyResponse>;
    submitBatch(body: NodeJS.ReadableStream, contentLength: number, multipartContentType: string, options: Models.ServiceSubmitBatchOptionalParams, context: Context): Promise<Models.ServiceSubmitBatchResponse>;
    /**
     * Set blob service properties.
     *
     * @param {Models.StorageServiceProperties} storageServiceProperties
     * @param {Models.ServiceSetPropertiesOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ServiceSetPropertiesResponse>}
     * @memberof ServiceHandler
     */
    setProperties(storageServiceProperties: Models.StorageServiceProperties, options: Models.ServiceSetPropertiesOptionalParams, context: Context): Promise<Models.ServiceSetPropertiesResponse>;
    /**
     * Get blob service properties.
     *
     * @param {Models.ServiceGetPropertiesOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ServiceGetPropertiesResponse>}
     * @memberof ServiceHandler
     */
    getProperties(options: Models.ServiceGetPropertiesOptionalParams, context: Context): Promise<Models.ServiceGetPropertiesResponse>;
    getStatistics(options: Models.ServiceGetStatisticsOptionalParams, context: Context): Promise<Models.ServiceGetStatisticsResponse>;
    /**
     * List containers.
     *
     * @param {Models.ServiceListContainersSegmentOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ServiceListContainersSegmentResponse>}
     * @memberof ServiceHandler
     */
    listContainersSegment(options: Models.ServiceListContainersSegmentOptionalParams, context: Context): Promise<Models.ServiceListContainersSegmentResponse>;
    getAccountInfo(context: Context): Promise<Models.ServiceGetAccountInfoResponse>;
    getAccountInfoWithHead(context: Context): Promise<Models.ServiceGetAccountInfoResponse>;
}
//# sourceMappingURL=ServiceHandler.d.ts.map