/// <reference types="node" />
import { PathLike } from "fs";
/**
 * Generates a hash signature for an HTTP request or for a SAS.
 *
 * @param {string} stringToSign
 * @param {key} key
 * @returns {string}
 */
export declare function computeHMACSHA256(stringToSign: string, key: Buffer): string;
/**
 * Rounds a date off to seconds.
 *
 * @export
 * @param {Date} date
 * @param {boolean} [withMilliseconds=true] If true, YYYY-MM-DDThh:mm:ss.fffffffZ will be returned;
 *                                          If false, YYYY-MM-DDThh:mm:ssZ will be returned.
 * @returns {string} Date string in ISO8061 format, with or without 7 milliseconds component
 */
export declare function truncatedISO8061Date(date: Date, withMilliseconds?: boolean): string;
export declare function newEtag(): string;
export declare function streamToLocalFile(stream: NodeJS.ReadableStream, path: PathLike): Promise<void>;
export declare function getMD5FromStream(stream: NodeJS.ReadableStream): Promise<Uint8Array>;
export declare function getMD5FromString(text: string): Promise<Uint8Array>;
/**
 * Get URL query key value pairs from an URL string.
 *
 * @export
 * @param {string} url
 * @returns {{[key: string]: string}}
 */
export declare function getURLQueries(url: string): {
    [key: string]: string;
};
/**
 * Default range value [0, Infinite] will be returned if all parameters not provided.
 *
 * @export
 * @param {string} [rangeHeaderValue]
 * @param {string} [xMsRangeHeaderValue]
 * @returns {[number, number]}
 */
export declare function deserializeRangeHeader(rangeHeaderValue?: string, xMsRangeHeaderValue?: string): [number, number];
/**
 * Deserialize range header into valid page ranges.
 * For example, "bytes=0-1023" will return [0, 1023].
 *
 * Default range value [0, Infinite] will be returned if all parameters not provided.
 *
 * @private
 * @param {string} [rangeHeaderValue]
 * @param {string} [xMsRangeHeaderValue]
 * @returns {([number, number] | undefined)}
 */
export declare function deserializePageBlobRangeHeader(rangeHeaderValue?: string, xMsRangeHeaderValue?: string, force512boundary?: boolean): [number, number];
/**
 * Remove double Quotation mark from ListBlob returned Etag, to align with server
 *
 * @param {string} [inputEtag]
 * @returns {string}
 */
export declare function removeQuotationFromListBlobEtag(inputEtag: string): string;
//# sourceMappingURL=utils.d.ts.map