import IExtentMetadataStore, { IExtentModel } from "./IExtentMetadataStore";
/**
 * This is a metadata source implementation for extent management based on loki DB.
 *
 * It contains following collection and documents:
 *
 * -- EXTENTS_COLLECTION     // Collections maintain extents information, including extentID, mapped local file path
 *                           // Unique document properties: id, path
 *
 * @export
 * @class LokiExtentMetadata
 * @implements {IExtentMetadata}
 */
export default class LokiExtentMetadata implements IExtentMetadataStore {
    readonly lokiDBPath: string;
    private readonly db;
    private initialized;
    private closed;
    private readonly EXTENTS_COLLECTION;
    constructor(lokiDBPath: string);
    isInitialized(): boolean;
    isClosed(): boolean;
    init(): Promise<void>;
    /**
     * Close loki DB.
     *
     * @returns {Promise<void>}
     * @memberof LokiBlobDataStore
     */
    close(): Promise<void>;
    /**
     * Clean LokiExtentMetadata.
     *
     * @returns {Promise<void>}
     * @memberof LokiExtentMetadata
     */
    clean(): Promise<void>;
    /**
     * Update the extent status in DB. A new item will be created if the extent does not exists.
     *
     * @param {IExtentModel} extent
     * @returns {Promise<void>}
     * @memberof LokiExtentMetadata
     */
    updateExtent(extent: IExtentModel): Promise<void>;
    /**
     * List extents.
     *
     * @param {string} [id]
     * @param {number} [maxResults]
     * @param {number} [marker]
     * @param {Date} [queryTime]
     * @param {number} [protectTimeInMs]
     * @returns {(Promise<[IExtentModel[], number | undefined]>)}
     * @memberof LokiExtentMetadata
     */
    listExtents(id?: string, maxResults?: number, marker?: number, queryTime?: Date, protectTimeInMs?: number): Promise<[IExtentModel[], number | undefined]>;
    /**
     * Delete the extent metadata from DB with the extentId.
     *
     * @param {string} extentId
     * @returns {Promise<void>}
     * @memberof IExtentMetadata
     */
    deleteExtent(extentId: string): Promise<void>;
    iteratorExtents(): AsyncIterator<string[]>;
    /**
     * Get the persistencyId for a given extentId.
     *
     * @param {string} extentId
     * @returns {Promise<string>}
     * @memberof IExtentMetadata
     */
    getExtentLocationId(extentId: string): Promise<string>;
}
//# sourceMappingURL=LokiExtentMetadataStore.d.ts.map