import IAccountDataStore from "../../common/IAccountDataStore";
import ILogger from "../../common/ILogger";
import Context from "../generated/Context";
import IRequest from "../generated/IRequest";
import IAuthenticator from "./IAuthenticator";
export default class QueueSharedKeyAuthenticator implements IAuthenticator {
    private readonly dataStore;
    private readonly logger;
    constructor(dataStore: IAccountDataStore, logger: ILogger);
    validate(req: IRequest, context: Context): Promise<boolean | undefined>;
    /**
     * Retrieve header value according to shared key sign rules.
     * @see https://docs.microsoft.com/en-us/rest/api/storageservices/authenticate-with-shared-key
     *
     * @private
     * @param {WebResource} request
     * @param {string} headerName
     * @returns {string}
     * @memberof SharedKeyCredentialPolicy
     */
    private getHeaderValueToSign;
    /**
     * To construct the CanonicalizedHeaders portion of the signature string, follow these steps:
     * 1. Retrieve all headers for the resource that begin with x-ms-, including the x-ms-date header.
     * 2. Convert each HTTP header name to lowercase.
     * 3. Sort the headers lexicographically by header name, in ascending order.
     *    Each header may appear only once in the string.
     * 4. Replace any linear whitespace in the header value with a single space.
     * 5. Trim any whitespace around the colon in the header.
     * 6. Finally, append a new-line character to each canonicalized header in the resulting list.
     *    Construct the CanonicalizedHeaders string by concatenating all headers in this list into a single string.
     *
     * @private
     * @param {IRequest} request
     * @returns {string}
     * @memberof SharedKeyCredentialPolicy
     */
    private getCanonicalizedHeadersString;
    /**
     * Retrieves canonicalized resource string.
     *
     * @private
     * @param {IRequest} request
     * @returns {string}
     * @memberof SharedKeyCredentialPolicy
     */
    private getCanonicalizedResourceString;
    /**
     * Get the StringToSign of headers for SharedKey or SharedKeyLite
     *
     * @private
     * @param {"SharedKey" | "SharedKeyLite"} type
     * @param {IRequest} req
     * @returns {string}
     * @memberof QueueSharedKeyAuthenticator
     */
    private getHeadersToSign;
}
//# sourceMappingURL=QueueSharedKeyAuthenticator.d.ts.map