import * as Models from "../generated/artifacts/models";
import Context from "../generated/Context";
import IMessagesHandler from "../generated/handlers/IMessagesHandler";
import BaseHandler from "./BaseHandler";
/**
 * MessagesHandler handles Azure Storage messages related requests.
 *
 * @export
 * @class MessagesHandler
 * @implements {IMessagesHandler}
 */
export default class MessagesHandler extends BaseHandler implements IMessagesHandler {
    /**
     * Dequeue the messages.
     *
     * @param {Models.MessagesDequeueOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.MessagesDequeueResponse>}
     * @memberof MessagesHandler
     */
    dequeue(options: Models.MessagesDequeueOptionalParams, context: Context): Promise<Models.MessagesDequeueResponse>;
    /**
     * Clear the messages in a queue
     *
     * @param {Models.MessagesClearOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.MessagesClearResponse>}
     * @memberof MessagesHandler
     */
    clear(options: Models.MessagesClearOptionalParams, context: Context): Promise<Models.MessagesClearResponse>;
    /**
     * Enqueue a message
     *
     * @param {Models.QueueMessage} queueMessage
     * @param {Models.MessagesEnqueueOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.MessagesEnqueueResponse>}
     * @memberof MessagesHandler
     */
    enqueue(queueMessage: Models.QueueMessage, options: Models.MessagesEnqueueOptionalParams, context: Context): Promise<Models.MessagesEnqueueResponse>;
    /**
     * get the peek messages without altering the visibility
     *
     * @param {Models.MessagesPeekOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.MessagesPeekResponse>}
     * @memberof MessagesHandler
     */
    peek(options: Models.MessagesPeekOptionalParams, context: Context): Promise<Models.MessagesPeekResponse>;
}
//# sourceMappingURL=MessagesHandler.d.ts.map