import * as Models from "../generated/artifacts/models";
import Context from "../generated/Context";
import IQueueHandler from "../generated/handlers/IQueueHandler";
import BaseHandler from "./BaseHandler";
/**
 * QueueHandler handles Azure Storage queue related requests.
 *
 * @export
 * @class QueueHandler
 * @implements {IQueueHandler}
 */
export default class QueueHandler extends BaseHandler implements IQueueHandler {
    /**
     * Create a queue with queueName.
     *
     * @param {Models.QueueCreateOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.QueueCreateResponse>}
     * @memberof QueueHandler
     */
    create(options: Models.QueueCreateOptionalParams, context: Context): Promise<Models.QueueCreateResponse>;
    /**
     * Delete a queue according to its name.
     *
     * @param {Models.QueueDeleteMethodOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.QueueDeleteResponse>}
     * @memberof QueueHandler
     */
    delete(options: Models.QueueDeleteMethodOptionalParams, context: Context): Promise<Models.QueueDeleteResponse>;
    /**
     * Get queue metadata.
     *
     * @param {Models.QueueGetPropertiesOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.QueueGetPropertiesResponse>}
     * @memberof QueueHandler
     */
    getProperties(options: Models.QueueGetPropertiesOptionalParams, context: Context): Promise<Models.QueueGetPropertiesResponse>;
    /**
     * Get queue metadata with Head.
     *
     * @param {Models.QueueGetPropertiesWithHeadOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.QueueGetPropertiesWithHeadResponse>}
     * @memberof QueueHandler
     */
    getPropertiesWithHead(options: Models.QueueGetPropertiesWithHeadOptionalParams, context: Context): Promise<Models.QueueGetPropertiesWithHeadResponse>;
    /**
     * Set queue metadata.
     *
     * @param {Models.QueueSetMetadataOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.QueueSetMetadataResponse>}
     * @memberof QueueHandler
     */
    setMetadata(options: Models.QueueSetMetadataOptionalParams, context: Context): Promise<Models.QueueSetMetadataResponse>;
    /**
     * Get queue access policies.
     *
     * @param {Models.QueueGetAccessPolicyOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.QueueGetAccessPolicyResponse>}
     * @memberof ContainerHandler
     */
    getAccessPolicy(options: Models.QueueGetAccessPolicyOptionalParams, context: Context): Promise<Models.QueueGetAccessPolicyResponse>;
    /**
     * Get queue access policies with Head.
     *
     * @param {Models.QueueGetAccessPolicyWithHeadOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.QueueGetAccessPolicyWithHeadResponse>}
     * @memberof QueueHandler
     */
    getAccessPolicyWithHead(options: Models.QueueGetAccessPolicyWithHeadOptionalParams, context: Context): Promise<Models.QueueGetAccessPolicyWithHeadResponse>;
    /**
     * Set queue access policies.
     *
     * @param {Models.QueueSetAccessPolicyOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.QueueSetAccessPolicyResponse>}
     * @memberof ContainerHandler
     */
    setAccessPolicy(options: Models.QueueSetAccessPolicyOptionalParams, context: Context): Promise<Models.QueueSetAccessPolicyResponse>;
    /**
     * Parse and retrive the original metadata name headers array to preserve its case.
     *
     * @private
     * @param {({ [propertyName: string]: string } | undefined)} reqMetadata
     * @param {{ [id: string]: string }} headers
     * @returns
     * @memberof QueueHandler
     */
    private parseMetadata;
}
//# sourceMappingURL=QueueHandler.d.ts.map