/// <reference types="node" />
import { PathLike } from "fs";
/**
 * Generates a hash signature for an HTTP request or for a SAS.
 *
 * @param {string} stringToSign
 * @param {key} key
 * @returns {string}
 */
export declare function computeHMACSHA256(stringToSign: string, key: Buffer): string;
/**
 * Rounds a date off to seconds.
 *
 * @export
 * @param {Date} date
 * @param {boolean} [withMilliseconds=true] If true, YYYY-MM-DDThh:mm:ss.fffffffZ will be returned;
 *                                          If false, YYYY-MM-DDThh:mm:ssZ will be returned.
 * @returns {string} Date string in ISO8061 format, with or without 7 milliseconds component
 */
export declare function truncatedISO8061Date(date: Date, withMilliseconds?: boolean): string;
export declare function newEtag(): string;
export declare function streamToLocalFile(stream: NodeJS.ReadableStream, path: PathLike): Promise<void>;
export declare function getMD5FromStream(stream: NodeJS.ReadableStream): Promise<Uint8Array>;
export declare function getMD5FromString(text: string): Promise<Uint8Array>;
/**
 * Get URL query key value pairs from an URL string.
 *
 * @export
 * @param {string} url
 * @returns {{[key: string]: string}}
 */
export declare function getURLQueries(url: string): {
    [key: string]: string;
};
/**
 * Default range value [0, Infinite] will be returned if all parameters not provided.
 *
 * @export
 * @param {string} [rangeHeaderValue]
 * @param {string} [xMsRangeHeaderValue]
 * @returns {[number, number]}
 */
export declare function deserializeRangeHeader(rangeHeaderValue?: string, xMsRangeHeaderValue?: string): [number, number];
/**
 * Deserialize range header into valid page ranges.
 * For example, "bytes=0-1023" will return [0, 1023].
 *
 * Default range value [0, Infinite] will be returned if all parameters not provided.
 *
 * @private
 * @param {string} [rangeHeaderValue]
 * @param {string} [xMsRangeHeaderValue]
 * @returns {([number, number] | undefined)}
 */
/**
 * validate the input name for queue or container.
 * @see https://docs.microsoft.com/en-us/rest/api/storageservices/naming-queues-and-metadata
 *
 * @export
 * @param {string} name
 * @returns {nameValidateCode} //0 for valid, 1 for outOfRange, 2 for invalid.
 */
export declare function isValidName(name: string): nameValidateCode;
export declare enum nameValidateCode {
    valid = 0,
    outOfRange = 1,
    invalidUri = 2,
    invalidName = 3
}
/**
 * Generate a random code with given length
 *
 * @public
 * @param {number} len
 * @returns {string}
 * @memberof LokiQueueDataStore
 */
export declare function randomValueHex(len: number): string;
/**
 * Generate the popreceipt for a get messages request.
 *
 * @public
 * @param {Date} requestDate
 * @returns {string}
 * @memberof LokiQueueDataStore
 */
export declare function getPopReceipt(requestDate: Date): string;
/**
 * Read the text from a readStream to a string.
 *
 * @export
 * @param {NodeJS.ReadableStream} data
 * @returns {Promise<string>}
 */
export declare function readStreamToString(data: NodeJS.ReadableStream): Promise<string>;
/**
 * Get the byte size of a string in UTF8.
 *
 * @public
 * @param {Date} requestDate
 * @returns {string}
 * @memberof LokiQueueDataStore
 */
export declare function getUTF8ByteSize(text: string): number;
/**
 * Retrive the value from XML body without ignoring the empty characters.
 *
 * @export
 * @param {string} param
 * @param {boolean} [explicitChildrenWithOrder=false]
 * @returns {Promise<any>}
 */
export declare function parseXMLwithEmpty(param: string, explicitChildrenWithOrder?: boolean): Promise<any>;
//# sourceMappingURL=utils.d.ts.map